Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3323)

Unified Diff: chrome/browser/extensions/api/easy_unlock_private/easy_unlock_private_connection_manager.h

Issue 2849493002: [EasyUnlock] Fixing the setup connection finder and message format. (Closed)
Patch Set: date Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/easy_unlock_private/easy_unlock_private_connection_manager.h
diff --git a/chrome/browser/extensions/api/easy_unlock_private/easy_unlock_private_connection_manager.h b/chrome/browser/extensions/api/easy_unlock_private/easy_unlock_private_connection_manager.h
index a6d93474a130c0b031bfa43236495fde922414dd..905614f74121a1862bfa77a8e575f68240740cd6 100644
--- a/chrome/browser/extensions/api/easy_unlock_private/easy_unlock_private_connection_manager.h
+++ b/chrome/browser/extensions/api/easy_unlock_private/easy_unlock_private_connection_manager.h
@@ -47,11 +47,11 @@ class EasyUnlockPrivateConnectionManager
// |connection_id| is valid.
bool Disconnect(const Extension* extension, int connection_id);
// Sends |payload| through the connection with |connection_id|. Returns true
// if |connection_id| is valid.
bool SendMessage(const Extension* extension,
int connection_id,
- const std::string& payload);
+ const std::string& message_body);
// Returns the Bluetooth address of the device connected with a given
// |connection_id|, and an empty string if |connection_id| was not found.
@@ -47,11 +47,11 @@ class EasyUnlockPrivateConnectionManager
// |connection_id| is valid.
bool Disconnect(const Extension* extension, int connection_id);
- // Sends |payload| through the connection with |connection_id|. Returns true
- // if |connection_id| is valid.
+ // Sends |message_body| through the connection with |connection_id|. Returns
+ // true if |connection_id| is valid.
bool SendMessage(const Extension* extension,
int connection_id,

Powered by Google App Engine
This is Rietveld 408576698